 Reahl is a web application framework that allows a Python programmer to work in
 terms of useful abstractions - using a single programming language.

 This package contains add-on facilities using which you can process payments
 via PayPal.
